aboutsummaryrefslogtreecommitdiff
path: root/tools/buildman/toolchain.py
diff options
context:
space:
mode:
authorTom Rini <trini@konsulko.com>2022-08-05 13:22:44 -0400
committerTom Rini <trini@konsulko.com>2022-08-05 13:22:44 -0400
commit56edbb5eafc53cd7b34cd231ec11c7e5eb576c9f (patch)
tree2dd1ae00ca6f61d0efda20d930c2f33bdbb23457 /tools/buildman/toolchain.py
parent46b5c8ed017958fc387ab86c71ae6c90abb6793c (diff)
parentff75d6e03ee4346bbe9614f10949649bb704a7e9 (diff)
Merge branch '2022-08-05-buildman-integrate-boardscfg'
To quote Simon: This series drops the need for the genboardscfg.py script, so that the boards.cfg file is produced (and consumed) entirely within buildman. The file is not entirely removed since it does have some uses and we need some sort of cache for the information. The genboardscfg.py script is effectively incorporated in buildman. It also improves operation from an IDE with a new -I option and fixes up some of the pylint warnings in buildman. Finally, this series also fixes a bug which allows use to drop support for CONFIG_SYS_EXTRA_OPTIONS which is long-standing desire. It also fixes a minor bug that causes 'Invalid line' spam when checking for function bloat with the -B option.
Diffstat (limited to 'tools/buildman/toolchain.py')
-rw-r--r--tools/buildman/toolchain.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/tools/buildman/toolchain.py b/tools/buildman/toolchain.py
index 46a4e5ed40..fea40ba215 100644
--- a/tools/buildman/toolchain.py
+++ b/tools/buildman/toolchain.py
@@ -441,7 +441,7 @@ class Toolchains:
args = args[:m.start(0)] + value + args[m.end(0):]
return args
- def GetMakeArguments(self, board):
+ def GetMakeArguments(self, brd):
"""Returns 'make' arguments for a given board
The flags are in a section called 'make-flags'. Flags are named
@@ -462,13 +462,13 @@ class Toolchains:
A special 'target' variable is set to the board target.
Args:
board: Board object for the board to check.
Returns:
'make' flags for that board, or '' if none
"""
- self._make_flags['target'] = board.target
+ self._make_flags['target'] = brd.target
arg_str = self.ResolveReferences(self._make_flags,
- self._make_flags.get(board.target, ''))
+ self._make_flags.get(brd.target, ''))
args = re.findall("(?:\".*?\"|\S)+", arg_str)
i = 0
while i < len(args):
@@ -462,13 +462,13 @@ class Toolchains:
A special 'target' variable is set to the board target.
Args:
- board: Board object for the board to check.
+ brd: Board object for the board to check.
Returns:
'make' flags for that board, or '' if none